Hi,

The name of the macro MCLGETI obsolete.  It was made to use a network
interface pointer inside.  But, now it is just used to define a special
length and the interface pointer is discarded.

Thus, the following diff renames the macro to MCLGETL and removes the
dead parameter ifp.

OK?

Bye,
Jan

Index: share/man/man9/mbuf.9
===================================================================
RCS file: /cvs/src/share/man/man9/mbuf.9,v
retrieving revision 1.119
diff -u -p -r1.119 mbuf.9
--- share/man/man9/mbuf.9       8 Aug 2020 07:42:31 -0000       1.119
+++ share/man/man9/mbuf.9       7 Oct 2020 19:24:48 -0000
@@ -58,7 +58,7 @@
 .Nm m_devget ,
 .Nm m_apply ,
 .Nm MCLGET ,
-.Nm MCLGETI ,
+.Nm MCLGETL ,
 .Nm MEXTADD ,
 .Nm m_align ,
 .Nm M_READONLY ,
@@ -126,7 +126,7 @@
 "int (*func)(caddr_t, caddr_t, unsigned int)" "caddr_t fstate"
 .Fn MCLGET "struct mbuf *m" "int how"
 .Ft struct mbuf *
-.Fn MCLGETI "struct mbuf *m" "int how" "struct ifnet *ifp" "int len"
+.Fn MCLGETL "struct mbuf *m" "int how" "int len"
 .Fn MEXTADD "struct mbuf *m" "caddr_t buf" "u_int size" "int flags" \
 "void (*free)(caddr_t, u_int, void *)" "void *arg"
 .Ft void
@@ -721,7 +721,7 @@ See
 .Fn m_get
 for a description of
 .Fa how .
-.It Fn MCLGETI "struct mbuf *m" "int how" "struct ifnet *ifp" "int len"
+.It Fn MCLGETL "struct mbuf *m" "int how" "int len"
 If
 .Fa m
 is NULL, allocate it.
Index: sys/arch/octeon/dev/if_cnmac.c
===================================================================
RCS file: /cvs/src/sys/arch/octeon/dev/if_cnmac.c,v
retrieving revision 1.79
diff -u -p -r1.79 if_cnmac.c
--- sys/arch/octeon/dev/if_cnmac.c      4 Sep 2020 15:18:05 -0000       1.79
+++ sys/arch/octeon/dev/if_cnmac.c      7 Oct 2020 19:27:08 -0000
@@ -1106,7 +1106,7 @@ cnmac_mbuf_alloc(int n)
        paddr_t pktbuf;
 
        while (n > 0) {
-               m = MCLGETI(NULL, M_NOWAIT, NULL,
+               m = MCLGETL(NULL, M_NOWAIT,
                    OCTEON_POOL_SIZE_PKT + CACHELINESIZE);
                if (m == NULL || !ISSET(m->m_flags, M_EXT)) {
                        m_freem(m);
Index: sys/arch/octeon/dev/if_ogx.c
===================================================================
RCS file: /cvs/src/sys/arch/octeon/dev/if_ogx.c,v
retrieving revision 1.2
diff -u -p -r1.2 if_ogx.c
--- sys/arch/octeon/dev/if_ogx.c        9 Sep 2020 15:53:25 -0000       1.2
+++ sys/arch/octeon/dev/if_ogx.c        7 Oct 2020 19:27:25 -0000
@@ -1147,7 +1147,7 @@ ogx_load_mbufs(struct ogx_softc *sc, uns
        paddr_t pktbuf;
 
        for ( ; n > 0; n--) {
-               m = MCLGETI(NULL, M_NOWAIT, NULL, MCLBYTES);
+               m = MCLGETL(NULL, M_NOWAIT, MCLBYTES);
                if (m == NULL)
                        break;
 
Index: sys/arch/sparc64/dev/vnet.c
===================================================================
RCS file: /cvs/src/sys/arch/sparc64/dev/vnet.c,v
retrieving revision 1.62
diff -u -p -r1.62 vnet.c
--- sys/arch/sparc64/dev/vnet.c 10 Jul 2020 13:26:36 -0000      1.62
+++ sys/arch/sparc64/dev/vnet.c 7 Oct 2020 19:27:41 -0000
@@ -834,7 +834,7 @@ vnet_rx_vio_dring_data(struct vnet_softc
                                goto skip;
                        }
 
-                       m = MCLGETI(NULL, M_DONTWAIT, NULL, desc.nbytes);
+                       m = MCLGETL(NULL, M_DONTWAIT, desc.nbytes);
                        if (!m)
                                break;
                        m->m_len = m->m_pkthdr.len = desc.nbytes;
Index: sys/dev/fdt/if_dwge.c
===================================================================
RCS file: /cvs/src/sys/dev/fdt/if_dwge.c,v
retrieving revision 1.6
diff -u -p -r1.6 if_dwge.c
--- sys/dev/fdt/if_dwge.c       13 Sep 2020 01:54:05 -0000      1.6
+++ sys/dev/fdt/if_dwge.c       7 Oct 2020 19:28:00 -0000
@@ -1283,7 +1283,7 @@ dwge_alloc_mbuf(struct dwge_softc *sc, b
 {
        struct mbuf *m = NULL;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+       m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
        if (!m)
                return (NULL);
        m->m_len = m->m_pkthdr.len = MCLBYTES;
Index: sys/dev/fdt/if_dwxe.c
===================================================================
RCS file: /cvs/src/sys/dev/fdt/if_dwxe.c,v
retrieving revision 1.17
diff -u -p -r1.17 if_dwxe.c
--- sys/dev/fdt/if_dwxe.c       10 Jul 2020 13:26:36 -0000      1.17
+++ sys/dev/fdt/if_dwxe.c       7 Oct 2020 19:28:28 -0000
@@ -1342,7 +1342,7 @@ dwxe_alloc_mbuf(struct dwxe_softc *sc, b
 {
        struct mbuf *m = NULL;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+       m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
        if (!m)
                return (NULL);
        m->m_len = m->m_pkthdr.len = MCLBYTES;
Index: sys/dev/fdt/if_fec.c
===================================================================
RCS file: /cvs/src/sys/dev/fdt/if_fec.c,v
retrieving revision 1.10
diff -u -p -r1.10 if_fec.c
--- sys/dev/fdt/if_fec.c        10 Jul 2020 13:26:36 -0000      1.10
+++ sys/dev/fdt/if_fec.c        7 Oct 2020 19:28:41 -0000
@@ -1298,7 +1298,7 @@ fec_alloc_mbuf(struct fec_softc *sc, bus
 {
        struct mbuf *m = NULL;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+       m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
        if (!m)
                return (NULL);
        m->m_len = m->m_pkthdr.len = MCLBYTES;
Index: sys/dev/fdt/if_mvneta.c
===================================================================
RCS file: /cvs/src/sys/dev/fdt/if_mvneta.c,v
retrieving revision 1.13
diff -u -p -r1.13 if_mvneta.c
--- sys/dev/fdt/if_mvneta.c     10 Jul 2020 13:26:36 -0000      1.13
+++ sys/dev/fdt/if_mvneta.c     7 Oct 2020 19:28:54 -0000
@@ -1556,7 +1556,7 @@ mvneta_alloc_mbuf(struct mvneta_softc *s
 {
        struct mbuf *m = NULL;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+       m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
        if (!m)
                return (NULL);
        m->m_len = m->m_pkthdr.len = MCLBYTES;
Index: sys/dev/fdt/if_mvpp.c
===================================================================
RCS file: /cvs/src/sys/dev/fdt/if_mvpp.c,v
retrieving revision 1.27
diff -u -p -r1.27 if_mvpp.c
--- sys/dev/fdt/if_mvpp.c       22 Aug 2020 12:34:14 -0000      1.27
+++ sys/dev/fdt/if_mvpp.c       7 Oct 2020 19:29:12 -0000
@@ -2877,7 +2877,7 @@ mvpp2_alloc_mbuf(struct mvpp2_softc *sc,
 {
        struct mbuf *m = NULL;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+       m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
        if (!m)
                return (NULL);
        m->m_len = m->m_pkthdr.len = MCLBYTES;
Index: sys/dev/ic/bcmgenet.c
===================================================================
RCS file: /cvs/src/sys/dev/ic/bcmgenet.c,v
retrieving revision 1.3
diff -u -p -r1.3 bcmgenet.c
--- sys/dev/ic/bcmgenet.c       10 Jul 2020 13:26:37 -0000      1.3
+++ sys/dev/ic/bcmgenet.c       7 Oct 2020 19:30:51 -0000
@@ -300,7 +300,7 @@ genet_alloc_mbufcl(struct genet_softc *s
 {
        struct mbuf *m;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+       m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
        if (m != NULL)
                m->m_pkthdr.len = m->m_len = m->m_ext.ext_size;
 
Index: sys/dev/ic/elink3.c
===================================================================
RCS file: /cvs/src/sys/dev/ic/elink3.c,v
retrieving revision 1.97
diff -u -p -r1.97 elink3.c
--- sys/dev/ic/elink3.c 10 Jul 2020 13:26:37 -0000      1.97
+++ sys/dev/ic/elink3.c 7 Oct 2020 19:31:23 -0000
@@ -1343,7 +1343,7 @@ epget(struct ep_softc *sc, int totlen)
        m = sc->mb[sc->next_mb];
        sc->mb[sc->next_mb] = NULL;
        if (m == NULL) {
-               m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+               m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
                /* If the queue is no longer full, refill. */
                if (!timeout_pending(&sc->sc_epmbuffill_tmo))
                        timeout_add(&sc->sc_epmbuffill_tmo, 1);
@@ -1609,7 +1609,7 @@ epmbuffill(void *v)
        s = splnet();
        for (i = 0; i < MAX_MBS; i++) {
                if (sc->mb[i] == NULL) {
-                       sc->mb[i] = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+                       sc->mb[i] = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
                        if (sc->mb[i] == NULL)
                                break;
                }
Index: sys/dev/ic/gem.c
===================================================================
RCS file: /cvs/src/sys/dev/ic/gem.c,v
retrieving revision 1.125
diff -u -p -r1.125 gem.c
--- sys/dev/ic/gem.c    10 Jul 2020 13:26:37 -0000      1.125
+++ sys/dev/ic/gem.c    7 Oct 2020 19:31:43 -0000
@@ -1057,7 +1057,7 @@ gem_add_rxbuf(struct gem_softc *sc, int 
        struct mbuf *m;
        int error;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+       m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
        if (!m)
                return (ENOBUFS);
        m->m_len = m->m_pkthdr.len = MCLBYTES;
Index: sys/dev/ic/hme.c
===================================================================
RCS file: /cvs/src/sys/dev/ic/hme.c,v
retrieving revision 1.82
diff -u -p -r1.82 hme.c
--- sys/dev/ic/hme.c    22 Jun 2020 02:27:04 -0000      1.82
+++ sys/dev/ic/hme.c    7 Oct 2020 19:31:57 -0000
@@ -1284,7 +1284,7 @@ hme_newbuf(struct hme_softc *sc, struct 
         * until we're sure everything is a success.
         */
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+       m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
        if (!m)
                return (ENOBUFS);
 
Index: sys/dev/ic/re.c
===================================================================
RCS file: /cvs/src/sys/dev/ic/re.c,v
retrieving revision 1.207
diff -u -p -r1.207 re.c
--- sys/dev/ic/re.c     26 Aug 2020 03:29:06 -0000      1.207
+++ sys/dev/ic/re.c     7 Oct 2020 19:32:14 -0000
@@ -1125,7 +1125,7 @@ re_newbuf(struct rl_softc *sc)
        u_int32_t       cmdstat;
        int             error, idx;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, RL_FRAMELEN(sc->rl_max_mtu));
+       m = MCLGETL(NULL, M_DONTWAIT, RL_FRAMELEN(sc->rl_max_mtu));
        if (!m)
                return (ENOBUFS);
 
Index: sys/dev/ic/rt2860.c
===================================================================
RCS file: /cvs/src/sys/dev/ic/rt2860.c,v
retrieving revision 1.99
diff -u -p -r1.99 rt2860.c
--- sys/dev/ic/rt2860.c 10 Jul 2020 13:22:20 -0000      1.99
+++ sys/dev/ic/rt2860.c 7 Oct 2020 19:32:44 -0000
@@ -685,7 +685,7 @@ rt2860_alloc_rx_ring(struct rt2860_softc
                        goto fail;
                }
 
-               data->m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+               data->m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
                if (data->m == NULL) {
                        printf("%s: could not allocate Rx mbuf\n",
                            sc->sc_dev.dv_xname);
@@ -1304,7 +1304,7 @@ rt2860_rx_intr(struct rt2860_softc *sc)
                        goto skip;
                }
 
-               m1 = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+               m1 = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
                if (__predict_false(m1 == NULL)) {
                        ifp->if_ierrors++;
                        goto skip;
Index: sys/dev/ic/ti.c
===================================================================
RCS file: /cvs/src/sys/dev/ic/ti.c,v
retrieving revision 1.27
diff -u -p -r1.27 ti.c
--- sys/dev/ic/ti.c     10 Jul 2020 13:26:37 -0000      1.27
+++ sys/dev/ic/ti.c     7 Oct 2020 19:33:08 -0000
@@ -576,7 +576,7 @@ ti_newbuf_std(struct ti_softc *sc, int i
        sc->ti_cdata.ti_rx_std_map[i] = dmamap;
 
        if (m == NULL) {
-               m_new = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+               m_new = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
                if (m_new == NULL)
                        return (ENOBUFS);
 
@@ -695,7 +695,7 @@ ti_newbuf_jumbo(struct ti_softc *sc, int
                bus_dmamap_unload(sc->sc_dmatag, dmamap);
 
        if (m == NULL) {
-               m_new = MCLGETI(NULL, M_DONTWAIT, NULL, TI_JUMBO_FRAMELEN);
+               m_new = MCLGETL(NULL, M_DONTWAIT, TI_JUMBO_FRAMELEN);
                if (m_new == NULL)
                        return (ENOBUFS);
 
Index: sys/dev/ic/xl.c
===================================================================
RCS file: /cvs/src/sys/dev/ic/xl.c,v
retrieving revision 1.135
diff -u -p -r1.135 xl.c
--- sys/dev/ic/xl.c     10 Jul 2020 13:26:37 -0000      1.135
+++ sys/dev/ic/xl.c     7 Oct 2020 19:33:23 -0000
@@ -1081,7 +1081,7 @@ xl_newbuf(struct xl_softc *sc, struct xl
        struct mbuf     *m_new = NULL;
        bus_dmamap_t    map;
 
-       m_new = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+       m_new = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
        if (!m_new)
                return (ENOBUFS);
 
Index: sys/dev/pci/if_bge.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_bge.c,v
retrieving revision 1.392
diff -u -p -r1.392 if_bge.c
--- sys/dev/pci/if_bge.c        26 Jul 2020 17:44:15 -0000      1.392
+++ sys/dev/pci/if_bge.c        7 Oct 2020 19:33:56 -0000
@@ -1113,7 +1113,7 @@ bge_newbuf(struct bge_softc *sc, int i)
        struct mbuf             *m;
        int                     error;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, sc->bge_rx_std_len);
+       m = MCLGETL(NULL, M_DONTWAIT, sc->bge_rx_std_len);
        if (!m)
                return (ENOBUFS);
        m->m_len = m->m_pkthdr.len = sc->bge_rx_std_len;
@@ -1162,7 +1162,7 @@ bge_newbuf_jumbo(struct bge_softc *sc, i
        struct mbuf             *m;
        int                     error;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, BGE_JLEN);
+       m = MCLGETL(NULL, M_DONTWAIT, BGE_JLEN);
        if (!m)
                return (ENOBUFS);
        m->m_len = m->m_pkthdr.len = BGE_JUMBO_FRAMELEN;
Index: sys/dev/pci/if_bnx.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_bnx.c,v
retrieving revision 1.129
diff -u -p -r1.129 if_bnx.c
--- sys/dev/pci/if_bnx.c        10 Jul 2020 13:26:37 -0000      1.129
+++ sys/dev/pci/if_bnx.c        7 Oct 2020 19:34:13 -0000
@@ -3671,7 +3671,7 @@ bnx_get_buf(struct bnx_softc *sc, u_int1
            *prod_bseq);
 
        /* This is a new mbuf allocation. */
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, BNX_MAX_JUMBO_MRU);
+       m = MCLGETL(NULL, M_DONTWAIT, BNX_MAX_JUMBO_MRU);
        if (!m)
                return (0);
        m->m_len = m->m_pkthdr.len = BNX_MAX_JUMBO_MRU;
Index: sys/dev/pci/if_bnxt.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_bnxt.c,v
retrieving revision 1.26
diff -u -p -r1.26 if_bnxt.c
--- sys/dev/pci/if_bnxt.c       10 Jul 2020 13:26:37 -0000      1.26
+++ sys/dev/pci/if_bnxt.c       7 Oct 2020 19:34:30 -0000
@@ -1879,7 +1879,7 @@ bnxt_rx_fill_slots(struct bnxt_softc *sc
        p = *prod;
        for (fills = 0; fills < nslots; fills++) {
                bs = &slots[p];
-               m = MCLGETI(NULL, M_DONTWAIT, NULL, bufsize);
+               m = MCLGETL(NULL, M_DONTWAIT, bufsize);
                if (m == NULL)
                        break;
 
Index: sys/dev/pci/if_bwfm_pci.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_bwfm_pci.c,v
retrieving revision 1.37
diff -u -p -r1.37 if_bwfm_pci.c
--- sys/dev/pci/if_bwfm_pci.c   22 Jun 2020 02:31:32 -0000      1.37
+++ sys/dev/pci/if_bwfm_pci.c   7 Oct 2020 19:35:07 -0000
@@ -963,7 +963,7 @@ bwfm_pci_fill_rx_ioctl_ring(struct bwfm_
                req = bwfm_pci_ring_write_reserve(sc, &sc->sc_ctrl_submit);
                if (req == NULL)
                        break;
-               m = MCLGETI(NULL, M_DONTWAIT, NULL, MSGBUF_MAX_PKT_SIZE);
+               m = MCLGETL(NULL, M_DONTWAIT, MSGBUF_MAX_PKT_SIZE);
                if (m == NULL) {
                        bwfm_pci_ring_write_cancel(sc, &sc->sc_ctrl_submit, 1);
                        break;
@@ -1003,7 +1003,7 @@ bwfm_pci_fill_rx_buf_ring(struct bwfm_pc
                req = bwfm_pci_ring_write_reserve(sc, &sc->sc_rxpost_submit);
                if (req == NULL)
                        break;
-               m = MCLGETI(NULL, M_DONTWAIT, NULL, MSGBUF_MAX_PKT_SIZE);
+               m = MCLGETL(NULL, M_DONTWAIT, MSGBUF_MAX_PKT_SIZE);
                if (m == NULL) {
                        bwfm_pci_ring_write_cancel(sc, &sc->sc_rxpost_submit, 
1);
                        break;
@@ -1959,7 +1959,7 @@ bwfm_pci_msgbuf_query_dcmd(struct bwfm_s
        int s;
 
        buflen = min(*len, BWFM_DMA_H2D_IOCTL_BUF_LEN);
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, buflen);
+       m = MCLGETL(NULL, M_DONTWAIT, buflen);
        if (m == NULL)
                return 1;
        m->m_len = m->m_pkthdr.len = buflen;
Index: sys/dev/pci/if_em.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_em.c,v
retrieving revision 1.356
diff -u -p -r1.356 if_em.c
--- sys/dev/pci/if_em.c 12 Jul 2020 05:21:34 -0000      1.356
+++ sys/dev/pci/if_em.c 7 Oct 2020 19:35:25 -0000
@@ -2515,7 +2515,7 @@ em_get_buf(struct em_queue *que, int i)
 
        KASSERT(pkt->pkt_m == NULL);
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, EM_MCLBYTES);
+       m = MCLGETL(NULL, M_DONTWAIT, EM_MCLBYTES);
        if (m == NULL) {
                sc->mbuf_cluster_failed++;
                return (ENOBUFS);
Index: sys/dev/pci/if_iavf.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_iavf.c,v
retrieving revision 1.9
diff -u -p -r1.9 if_iavf.c
--- sys/dev/pci/if_iavf.c       10 Jul 2020 13:26:38 -0000      1.9
+++ sys/dev/pci/if_iavf.c       7 Oct 2020 19:35:40 -0000
@@ -2067,7 +2067,7 @@ iavf_rxfill(struct iavf_softc *sc, struc
        do {
                rxm = &rxr->rxr_maps[prod];
 
-               m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES + ETHER_ALIGN);
+               m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES + ETHER_ALIGN);
                if (m == NULL)
                        break;
                m->m_data += (m->m_ext.ext_size - (MCLBYTES + ETHER_ALIGN));
Index: sys/dev/pci/if_iwm.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_iwm.c,v
retrieving revision 1.314
diff -u -p -r1.314 if_iwm.c
--- sys/dev/pci/if_iwm.c        26 Aug 2020 17:12:00 -0000      1.314
+++ sys/dev/pci/if_iwm.c        7 Oct 2020 19:36:17 -0000
@@ -3790,7 +3790,7 @@ iwm_rx_addbuf(struct iwm_softc *sc, int 
        if (size <= MCLBYTES) {
                MCLGET(m, M_DONTWAIT);
        } else {
-               MCLGETI(m, M_DONTWAIT, NULL, IWM_RBUF_SIZE);
+               MCLGETL(m, M_DONTWAIT, IWM_RBUF_SIZE);
        }
        if ((m->m_flags & M_EXT) == 0) {
                m_freem(m);
@@ -4560,7 +4560,7 @@ iwm_send_cmd(struct iwm_softc *sc, struc
                        err = EINVAL;
                        goto out;
                }
-               m = MCLGETI(NULL, M_DONTWAIT, NULL, totlen);
+               m = MCLGETL(NULL, M_DONTWAIT, totlen);
                if (m == NULL) {
                        printf("%s: could not get fw cmd mbuf (%zd bytes)\n",
                            DEVNAME(sc), totlen);
Index: sys/dev/pci/if_iwn.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_iwn.c,v
retrieving revision 1.241
diff -u -p -r1.241 if_iwn.c
--- sys/dev/pci/if_iwn.c        27 Jul 2020 07:24:03 -0000      1.241
+++ sys/dev/pci/if_iwn.c        7 Oct 2020 19:36:48 -0000
@@ -1201,7 +1201,7 @@ iwn_alloc_rx_ring(struct iwn_softc *sc, 
                        goto fail;
                }
 
-               data->m = MCLGETI(NULL, M_DONTWAIT, NULL, IWN_RBUF_SIZE);
+               data->m = MCLGETL(NULL, M_DONTWAIT, IWN_RBUF_SIZE);
                if (data->m == NULL) {
                        printf("%s: could not allocate RX mbuf\n",
                            sc->sc_dev.dv_xname);
@@ -2060,7 +2060,7 @@ iwn_rx_done(struct iwn_softc *sc, struct
                return;
        }
 
-       m1 = MCLGETI(NULL, M_DONTWAIT, NULL, IWN_RBUF_SIZE);
+       m1 = MCLGETL(NULL, M_DONTWAIT, IWN_RBUF_SIZE);
        if (m1 == NULL) {
                ic->ic_stats.is_rx_nombuf++;
                ifp->if_ierrors++;
Index: sys/dev/pci/if_iwx.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_iwx.c,v
retrieving revision 1.44
diff -u -p -r1.44 if_iwx.c
--- sys/dev/pci/if_iwx.c        26 Aug 2020 17:12:00 -0000      1.44
+++ sys/dev/pci/if_iwx.c        7 Oct 2020 19:37:09 -0000
@@ -3171,7 +3171,7 @@ iwx_rx_addbuf(struct iwx_softc *sc, int 
        if (size <= MCLBYTES) {
                MCLGET(m, M_DONTWAIT);
        } else {
-               MCLGETI(m, M_DONTWAIT, NULL, IWX_RBUF_SIZE);
+               MCLGETL(m, M_DONTWAIT, IWX_RBUF_SIZE);
        }
        if ((m->m_flags & M_EXT) == 0) {
                m_freem(m);
@@ -3820,7 +3820,7 @@ iwx_send_cmd(struct iwx_softc *sc, struc
                        err = EINVAL;
                        goto out;
                }
-               m = MCLGETI(NULL, M_DONTWAIT, NULL, totlen);
+               m = MCLGETL(NULL, M_DONTWAIT, totlen);
                if (m == NULL) {
                        printf("%s: could not get fw cmd mbuf (%zd bytes)\n",
                            DEVNAME(sc), totlen);
Index: sys/dev/pci/if_ix.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_ix.c,v
retrieving revision 1.172
diff -u -p -r1.172 if_ix.c
--- sys/dev/pci/if_ix.c 18 Jul 2020 07:18:22 -0000      1.172
+++ sys/dev/pci/if_ix.c 7 Oct 2020 19:37:32 -0000
@@ -2649,7 +2649,7 @@ ixgbe_get_buf(struct rx_ring *rxr, int i
        }
 
        /* needed in any case so prealocate since this one will fail for sure */
-       mp = MCLGETI(NULL, M_DONTWAIT, NULL, sc->rx_mbuf_sz);
+       mp = MCLGETL(NULL, M_DONTWAIT, sc->rx_mbuf_sz);
        if (!mp)
                return (ENOBUFS);
 
Index: sys/dev/pci/if_ixl.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_ixl.c,v
retrieving revision 1.68
diff -u -p -r1.68 if_ixl.c
--- sys/dev/pci/if_ixl.c        16 Jul 2020 03:04:50 -0000      1.68
+++ sys/dev/pci/if_ixl.c        7 Oct 2020 19:37:49 -0000
@@ -3213,7 +3213,7 @@ ixl_rxfill(struct ixl_softc *sc, struct 
        do {
                rxm = &rxr->rxr_maps[prod];
 
-               m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES + ETHER_ALIGN);
+               m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES + ETHER_ALIGN);
                if (m == NULL)
                        break;
                m->m_data += (m->m_ext.ext_size - (MCLBYTES + ETHER_ALIGN));
Index: sys/dev/pci/if_lge.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_lge.c,v
retrieving revision 1.75
diff -u -p -r1.75 if_lge.c
--- sys/dev/pci/if_lge.c        10 Jul 2020 13:26:38 -0000      1.75
+++ sys/dev/pci/if_lge.c        7 Oct 2020 19:38:05 -0000
@@ -626,7 +626,7 @@ lge_newbuf(struct lge_softc *sc, struct 
        struct mbuf             *m_new = NULL;
 
        if (m == NULL) {
-               m_new = MCLGETI(NULL, M_DONTWAIT, NULL, LGE_JLEN);
+               m_new = MCLGETL(NULL, M_DONTWAIT, LGE_JLEN);
                if (m_new == NULL)
                        return (ENOBUFS);
        } else {
Index: sys/dev/pci/if_mcx.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_mcx.c,v
retrieving revision 1.72
diff -u -p -r1.72 if_mcx.c
--- sys/dev/pci/if_mcx.c        21 Aug 2020 04:47:52 -0000      1.72
+++ sys/dev/pci/if_mcx.c        7 Oct 2020 19:38:18 -0000
@@ -6403,7 +6403,7 @@ mcx_rx_fill_slots(struct mcx_softc *sc, 
        rqe = ring;
        for (fills = 0; fills < nslots; fills++) {
                ms = &slots[slot];
-               m = MCLGETI(NULL, M_DONTWAIT, NULL, sc->sc_rxbufsz);
+               m = MCLGETL(NULL, M_DONTWAIT, sc->sc_rxbufsz);
                if (m == NULL)
                        break;
 
Index: sys/dev/pci/if_msk.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_msk.c,v
retrieving revision 1.135
diff -u -p -r1.135 if_msk.c
--- sys/dev/pci/if_msk.c        10 Jul 2020 13:26:38 -0000      1.135
+++ sys/dev/pci/if_msk.c        7 Oct 2020 19:38:32 -0000
@@ -474,7 +474,7 @@ msk_newbuf(struct sk_if_softc *sc_if)
        uint32_t                hiaddr;
        unsigned int            pktlen = sc_if->sk_pktlen + ETHER_ALIGN;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, pktlen);
+       m = MCLGETL(NULL, M_DONTWAIT, pktlen);
        if (m == NULL)
                return (0);
        m->m_len = m->m_pkthdr.len = pktlen;
Index: sys/dev/pci/if_myx.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_myx.c,v
retrieving revision 1.111
diff -u -p -r1.111 if_myx.c
--- sys/dev/pci/if_myx.c        17 Jul 2020 03:37:36 -0000      1.111
+++ sys/dev/pci/if_myx.c        7 Oct 2020 19:48:52 -0000
@@ -1967,7 +1967,7 @@ myx_mcl_small(void)
 {
        struct mbuf *m;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, MYX_RXSMALL_SIZE);
+       m = MCLGETL(NULL, M_DONTWAIT, MYX_RXSMALL_SIZE);
        if (m == NULL)
                return (NULL);
 
Index: sys/dev/pci/if_nfe.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_nfe.c,v
retrieving revision 1.122
diff -u -p -r1.122 if_nfe.c
--- sys/dev/pci/if_nfe.c        10 Jul 2020 13:26:38 -0000      1.122
+++ sys/dev/pci/if_nfe.c        7 Oct 2020 19:39:12 -0000
@@ -697,7 +697,7 @@ nfe_rxeof(struct nfe_softc *sc)
                 * old mbuf. In the unlikely case that the old mbuf can't be
                 * reloaded either, explicitly panic.
                 */
-               mnew = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+               mnew = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
                if (mnew == NULL) {
                        ifp->if_ierrors++;
                        goto skip;
@@ -1210,7 +1210,7 @@ nfe_alloc_rx_ring(struct nfe_softc *sc, 
        for (i = 0; i < NFE_RX_RING_COUNT; i++) {
                data = &sc->rxq.data[i];
 
-               data->m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+               data->m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
                if (data->m == NULL) {
                        printf("%s: could not allocate rx mbuf\n",
                            sc->sc_dev.dv_xname);
Index: sys/dev/pci/if_nge.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_nge.c,v
retrieving revision 1.94
diff -u -p -r1.94 if_nge.c
--- sys/dev/pci/if_nge.c        10 Jul 2020 13:26:38 -0000      1.94
+++ sys/dev/pci/if_nge.c        7 Oct 2020 19:39:27 -0000
@@ -962,7 +962,7 @@ nge_newbuf(struct nge_softc *sc, struct 
        struct mbuf             *m_new = NULL;
 
        if (m == NULL) {
-               m_new = MCLGETI(NULL, M_DONTWAIT, NULL, NGE_MCLBYTES);
+               m_new = MCLGETL(NULL, M_DONTWAIT, NGE_MCLBYTES);
                if (m_new == NULL)
                        return (ENOBUFS);
        } else {
Index: sys/dev/pci/if_oce.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_oce.c,v
retrieving revision 1.103
diff -u -p -r1.103 if_oce.c
--- sys/dev/pci/if_oce.c        10 Jul 2020 13:26:38 -0000      1.103
+++ sys/dev/pci/if_oce.c        7 Oct 2020 19:39:43 -0000
@@ -1761,7 +1761,7 @@ oce_get_buf(struct oce_rq *rq)
        if ((pkt = oce_pkt_get(&rq->pkt_free)) == NULL)
                return (0);
 
-       pkt->mbuf = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+       pkt->mbuf = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
        if (pkt->mbuf == NULL) {
                oce_pkt_put(&rq->pkt_free, pkt);
                return (0);
Index: sys/dev/pci/if_rge.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_rge.c,v
retrieving revision 1.6
diff -u -p -r1.6 if_rge.c
--- sys/dev/pci/if_rge.c        7 Aug 2020 13:53:58 -0000       1.6
+++ sys/dev/pci/if_rge.c        7 Oct 2020 19:39:59 -0000
@@ -1054,7 +1054,7 @@ rge_newbuf(struct rge_softc *sc)
        bus_dmamap_t rxmap;
        int idx;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, sc->rge_rxbufsz);
+       m = MCLGETL(NULL, M_DONTWAIT, sc->rge_rxbufsz);
        if (m == NULL)
                return (ENOBUFS);
 
Index: sys/dev/pci/if_rtwn.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_rtwn.c,v
retrieving revision 1.36
diff -u -p -r1.36 if_rtwn.c
--- sys/dev/pci/if_rtwn.c       12 Sep 2019 12:55:07 -0000      1.36
+++ sys/dev/pci/if_rtwn.c       7 Oct 2020 19:40:30 -0000
@@ -545,7 +545,7 @@ rtwn_alloc_rx_list(struct rtwn_pci_softc
                        goto fail;
                }
 
-               rx_data->m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+               rx_data->m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
                if (rx_data->m == NULL) {
                        printf("%s: could not allocate rx mbuf\n",
                            sc->sc_dev.dv_xname);
@@ -887,7 +887,7 @@ rtwn_rx_frame(struct rtwn_pci_softc *sc,
        DPRINTFN(5, ("Rx frame len=%d rate=%d infosz=%d shift=%d rssi=%d\n",
            pktlen, rate, infosz, shift, rssi));
 
-       m1 = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+       m1 = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
        if (m1 == NULL) {
                ifp->if_ierrors++;
                return;
Index: sys/dev/pci/if_se.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_se.c,v
retrieving revision 1.21
diff -u -p -r1.21 if_se.c
--- sys/dev/pci/if_se.c 10 Jul 2020 13:26:38 -0000      1.21
+++ sys/dev/pci/if_se.c 7 Oct 2020 19:41:16 -0000
@@ -847,11 +847,11 @@ se_newbuf(struct se_softc *sc, uint i)
        struct mbuf *m;
        int rc;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+       m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
        if (m == NULL) {
 #ifdef SE_DEBUG
                if (ifp->if_flags & IFF_DEBUG)
-                       printf("%s: MCLGETI failed\n", ifp->if_xname);
+                       printf("%s: MCLGETL failed\n", ifp->if_xname);
 #endif
                return ENOBUFS;
        }
Index: sys/dev/pci/if_sis.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_sis.c,v
retrieving revision 1.138
diff -u -p -r1.138 if_sis.c
--- sys/dev/pci/if_sis.c        16 Jul 2020 00:52:33 -0000      1.138
+++ sys/dev/pci/if_sis.c        7 Oct 2020 19:41:34 -0000
@@ -1323,7 +1323,7 @@ sis_newbuf(struct sis_softc *sc, struct 
        if (c == NULL)
                return (EINVAL);
 
-       m_new = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+       m_new = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
        if (!m_new)
                return (ENOBUFS);
 
Index: sys/dev/pci/if_sk.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_sk.c,v
retrieving revision 1.191
diff -u -p -r1.191 if_sk.c
--- sys/dev/pci/if_sk.c 10 Jul 2020 13:26:38 -0000      1.191
+++ sys/dev/pci/if_sk.c 7 Oct 2020 19:41:52 -0000
@@ -622,7 +622,7 @@ sk_newbuf(struct sk_if_softc *sc_if)
        int                     error;
        uint64_t                dva;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, SK_JLEN);
+       m = MCLGETL(NULL, M_DONTWAIT, SK_JLEN);
        if (m == NULL)
                return (ENOBUFS);
 
Index: sys/dev/pci/if_vic.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_vic.c,v
retrieving revision 1.101
diff -u -p -r1.101 if_vic.c
--- sys/dev/pci/if_vic.c        10 Jul 2020 13:26:38 -0000      1.101
+++ sys/dev/pci/if_vic.c        7 Oct 2020 19:42:05 -0000
@@ -1311,7 +1311,7 @@ vic_alloc_mbuf(struct vic_softc *sc, bus
 {
        struct mbuf *m = NULL;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, pktlen);
+       m = MCLGETL(NULL, M_DONTWAIT, pktlen);
        if (!m)
                return (NULL);
        m->m_data += ETHER_ALIGN;
Index: sys/dev/pci/if_vmx.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_vmx.c,v
retrieving revision 1.64
diff -u -p -r1.64 if_vmx.c
--- sys/dev/pci/if_vmx.c        10 Jul 2020 13:26:38 -0000      1.64
+++ sys/dev/pci/if_vmx.c        7 Oct 2020 19:42:18 -0000
@@ -652,7 +652,7 @@ vmxnet3_rxfill(struct vmxnet3_rxring *ri
        for (slots = if_rxr_get(&ring->rxr, NRXDESC); slots > 0; slots--) {
                KASSERT(ring->m[prod] == NULL);
 
-               m = MCLGETI(NULL, M_DONTWAIT, NULL, JUMBO_LEN);
+               m = MCLGETL(NULL, M_DONTWAIT, JUMBO_LEN);
                if (m == NULL)
                        break;
 
Index: sys/dev/pci/if_vr.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_vr.c,v
retrieving revision 1.156
diff -u -p -r1.156 if_vr.c
--- sys/dev/pci/if_vr.c 10 Jul 2020 13:26:38 -0000      1.156
+++ sys/dev/pci/if_vr.c 7 Oct 2020 19:42:36 -0000
@@ -1699,7 +1699,7 @@ vr_alloc_mbuf(struct vr_softc *sc, struc
        if (r == NULL)
                return (EINVAL);
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+       m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
        if (!m)
                return (ENOBUFS);
 
Index: sys/dev/pci/if_wpi.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_wpi.c,v
retrieving revision 1.153
diff -u -p -r1.153 if_wpi.c
--- sys/dev/pci/if_wpi.c        10 Jul 2020 13:22:21 -0000      1.153
+++ sys/dev/pci/if_wpi.c        7 Oct 2020 19:43:17 -0000
@@ -674,7 +674,7 @@ wpi_alloc_rx_ring(struct wpi_softc *sc, 
                        goto fail;
                }
 
-               data->m = MCLGETI(NULL, M_DONTWAIT, NULL, WPI_RBUF_SIZE);
+               data->m = MCLGETL(NULL, M_DONTWAIT, WPI_RBUF_SIZE);
                if (data->m == NULL) {
                        printf("%s: could not allocate RX mbuf\n",
                            sc->sc_dev.dv_xname);
@@ -1216,7 +1216,7 @@ wpi_rx_done(struct wpi_softc *sc, struct
                return;
        }
 
-       m1 = MCLGETI(NULL, M_DONTWAIT, NULL, WPI_RBUF_SIZE);
+       m1 = MCLGETL(NULL, M_DONTWAIT, WPI_RBUF_SIZE);
        if (m1 == NULL) {
                ic->ic_stats.is_rx_nombuf++;
                ifp->if_ierrors++;
Index: sys/dev/pci/if_xge.c
===================================================================
RCS file: /cvs/src/sys/dev/pci/if_xge.c,v
retrieving revision 1.79
diff -u -p -r1.79 if_xge.c
--- sys/dev/pci/if_xge.c        10 Jul 2020 13:26:40 -0000      1.79
+++ sys/dev/pci/if_xge.c        7 Oct 2020 19:43:41 -0000
@@ -1340,7 +1340,7 @@ xge_add_rxbuf(struct xge_softc *sc, int 
        MGETHDR(m[0], M_DONTWAIT, MT_DATA);
        if (m[0] == NULL)
                return (ENOBUFS);
-       MCLGETI(m[0], M_DONTWAIT, NULL, XGE_MAX_FRAMELEN + ETHER_ALIGN);
+       MCLGETL(m[0], M_DONTWAIT, XGE_MAX_FRAMELEN + ETHER_ALIGN);
        if ((m[0]->m_flags & M_EXT) == 0) {
                m_freem(m[0]);
                return (ENOBUFS);
Index: sys/dev/pv/if_hvn.c
===================================================================
RCS file: /cvs/src/sys/dev/pv/if_hvn.c,v
retrieving revision 1.42
diff -u -p -r1.42 if_hvn.c
--- sys/dev/pv/if_hvn.c 30 Aug 2020 10:36:33 -0000      1.42
+++ sys/dev/pv/if_hvn.c 7 Oct 2020 19:44:01 -0000
@@ -1473,7 +1473,7 @@ hvn_devget(struct hvn_softc *sc, caddr_t
        if (len + ETHER_ALIGN <= MHLEN)
                MGETHDR(m, M_NOWAIT, MT_DATA);
        else
-               m = MCLGETI(NULL, M_NOWAIT, NULL, len + ETHER_ALIGN);
+               m = MCLGETL(NULL, M_NOWAIT, len + ETHER_ALIGN);
        if (m == NULL)
                return (NULL);
        m->m_len = m->m_pkthdr.len = len;
Index: sys/dev/pv/if_vio.c
===================================================================
RCS file: /cvs/src/sys/dev/pv/if_vio.c,v
retrieving revision 1.18
diff -u -p -r1.18 if_vio.c
--- sys/dev/pv/if_vio.c 10 Jul 2020 13:26:40 -0000      1.18
+++ sys/dev/pv/if_vio.c 7 Oct 2020 19:44:17 -0000
@@ -904,7 +904,7 @@ vio_add_rx_mbuf(struct vio_softc *sc, in
        struct mbuf *m;
        int r;
 
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, MCLBYTES);
+       m = MCLGETL(NULL, M_DONTWAIT, MCLBYTES);
        if (m == NULL)
                return ENOBUFS;
        sc->sc_rx_mbufs[i] = m;
Index: sys/dev/pv/if_xnf.c
===================================================================
RCS file: /cvs/src/sys/dev/pv/if_xnf.c,v
retrieving revision 1.64
diff -u -p -r1.64 if_xnf.c
--- sys/dev/pv/if_xnf.c 10 Jul 2020 13:26:40 -0000      1.64
+++ sys/dev/pv/if_xnf.c 7 Oct 2020 19:44:31 -0000
@@ -855,7 +855,7 @@ xnf_rx_ring_fill(struct xnf_softc *sc)
                id = rxd->rxd_rsp.rxp_id;
                if (sc->sc_rx_buf[id])
                        break;
-               m = MCLGETI(NULL, M_DONTWAIT, NULL, XNF_MCLEN);
+               m = MCLGETL(NULL, M_DONTWAIT, XNF_MCLEN);
                if (m == NULL)
                        break;
                m->m_len = m->m_pkthdr.len = XNF_MCLEN;
Index: sys/dev/usb/if_uath.c
===================================================================
RCS file: /cvs/src/sys/dev/usb/if_uath.c,v
retrieving revision 1.85
diff -u -p -r1.85 if_uath.c
--- sys/dev/usb/if_uath.c       10 Jul 2020 13:22:21 -0000      1.85
+++ sys/dev/usb/if_uath.c       7 Oct 2020 19:44:55 -0000
@@ -587,7 +587,7 @@ uath_alloc_rx_data_list(struct uath_soft
                        error = ENOMEM;
                        goto fail;
                }
-               MCLGETI(data->m, M_DONTWAIT, NULL, sc->rxbufsz);
+               MCLGETL(data->m, M_DONTWAIT, sc->rxbufsz);
                if (!(data->m->m_flags & M_EXT)) {
                        printf("%s: could not allocate rx mbuf cluster\n",
                            sc->sc_dev.dv_xname);
@@ -1201,7 +1201,7 @@ uath_data_rxeof(struct usbd_xfer *xfer, 
                ifp->if_ierrors++;
                goto skip;
        }
-       MCLGETI(mnew, M_DONTWAIT, NULL, sc->rxbufsz);
+       MCLGETL(mnew, M_DONTWAIT, sc->rxbufsz);
        if (!(mnew->m_flags & M_EXT)) {
                printf("%s: could not allocate rx mbuf cluster\n",
                    sc->sc_dev.dv_xname);
Index: sys/kern/uipc_mbuf.c
===================================================================
RCS file: /cvs/src/sys/kern/uipc_mbuf.c,v
retrieving revision 1.275
diff -u -p -r1.275 uipc_mbuf.c
--- sys/kern/uipc_mbuf.c        21 Jun 2020 05:37:26 -0000      1.275
+++ sys/kern/uipc_mbuf.c        7 Oct 2020 19:45:44 -0000
@@ -565,7 +565,7 @@ m_defrag(struct mbuf *m, int how)
        if ((m0 = m_gethdr(how, m->m_type)) == NULL)
                return (ENOBUFS);
        if (m->m_pkthdr.len > MHLEN) {
-               MCLGETI(m0, how, NULL, m->m_pkthdr.len);
+               MCLGETL(m0, how, m->m_pkthdr.len);
                if (!(m0->m_flags & M_EXT)) {
                        m_free(m0);
                        return (ENOBUFS);
@@ -759,7 +759,7 @@ m_copyback(struct mbuf *m0, int off, int
                        }
 
                        if (off + len > MLEN) {
-                               MCLGETI(n, wait, NULL, off + len);
+                               MCLGETL(n, wait, off + len);
                                if (!(n->m_flags & M_EXT)) {
                                        m_free(n);
                                        error = ENOBUFS;
@@ -793,7 +793,7 @@ m_copyback(struct mbuf *m0, int off, int
                        }
 
                        if (len > MLEN) {
-                               MCLGETI(n, wait, NULL, len);
+                               MCLGETL(n, wait, len);
                                if (!(n->m_flags & M_EXT)) {
                                        m_free(n);
                                        error = ENOBUFS;
@@ -978,7 +978,7 @@ m_pullup(struct mbuf *m0, int len)
                        goto bad;
 
                if (space > MHLEN) {
-                       MCLGETI(m0, M_DONTWAIT, NULL, space);
+                       MCLGETL(m0, M_DONTWAIT, space);
                        if ((m0->m_flags & M_EXT) == 0)
                                goto bad;
                }
@@ -1175,7 +1175,7 @@ m_makespace(struct mbuf *m0, int skip, i
                if (remain > 0) {
                        MGET(n, M_DONTWAIT, m->m_type);
                        if (n && remain > MLEN) {
-                               MCLGETI(n, M_DONTWAIT, NULL, remain);
+                               MCLGETL(n, M_DONTWAIT, remain);
                                if ((n->m_flags & M_EXT) == 0) {
                                        m_free(n);
                                        n = NULL;
@@ -1441,7 +1441,7 @@ m_dup_pkt(struct mbuf *m0, unsigned int 
                goto fail;
 
        if (len > MHLEN) {
-               MCLGETI(m, wait, NULL, len);
+               MCLGETL(m, wait, len);
                if (!ISSET(m->m_flags, M_EXT))
                        goto fail;
        }
Index: sys/kern/uipc_mbuf2.c
===================================================================
RCS file: /cvs/src/sys/kern/uipc_mbuf2.c,v
retrieving revision 1.44
diff -u -p -r1.44 uipc_mbuf2.c
--- sys/kern/uipc_mbuf2.c       16 Jul 2019 21:41:37 -0000      1.44
+++ sys/kern/uipc_mbuf2.c       7 Oct 2020 19:46:02 -0000
@@ -184,7 +184,7 @@ m_pulldown(struct mbuf *m, int off, int 
        }
        MGET(o, M_DONTWAIT, m->m_type);
        if (o && len > MLEN) {
-               MCLGETI(o, M_DONTWAIT, NULL, len);
+               MCLGETL(o, M_DONTWAIT, len);
                if ((o->m_flags & M_EXT) == 0) {
                        m_free(o);
                        o = NULL;
@@ -235,7 +235,7 @@ m_dup1(struct mbuf *m, int off, int len,
                l = MLEN;
        }
        if (n && len > l) {
-               MCLGETI(n, wait, NULL, len);
+               MCLGETL(n, wait, len);
                if ((n->m_flags & M_EXT) == 0) {
                        m_free(n);
                        n = NULL;
Index: sys/kern/uipc_socket.c
===================================================================
RCS file: /cvs/src/sys/kern/uipc_socket.c,v
retrieving revision 1.249
diff -u -p -r1.249 uipc_socket.c
--- sys/kern/uipc_socket.c      29 Sep 2020 11:48:54 -0000      1.249
+++ sys/kern/uipc_socket.c      7 Oct 2020 19:46:27 -0000
@@ -597,9 +597,9 @@ m_getuio(struct mbuf **mp, int atomic, l
 
                resid = ulmin(resid, space);
                if (resid >= MINCLSIZE) {
-                       MCLGETI(m, M_NOWAIT, NULL, ulmin(resid, MAXMCLBYTES));
+                       MCLGETL(m, M_NOWAIT, ulmin(resid, MAXMCLBYTES));
                        if ((m->m_flags & M_EXT) == 0)
-                               MCLGETI(m, M_NOWAIT, NULL, MCLBYTES);
+                               MCLGETL(m, M_NOWAIT, MCLBYTES);
                        if ((m->m_flags & M_EXT) == 0)
                                goto nopages;
                        mlen = m->m_ext.ext_size;
Index: sys/net/bpf.c
===================================================================
RCS file: /cvs/src/sys/net/bpf.c,v
retrieving revision 1.192
diff -u -p -r1.192 bpf.c
--- sys/net/bpf.c       18 Jun 2020 23:32:00 -0000      1.192
+++ sys/net/bpf.c       7 Oct 2020 19:46:50 -0000
@@ -207,7 +207,7 @@ bpf_movein(struct uio *uio, struct bpf_d
        m->m_pkthdr.len = len - hlen;
 
        if (len > MHLEN) {
-               MCLGETI(m, M_WAIT, NULL, len);
+               MCLGETL(m, M_WAIT, len);
                if ((m->m_flags & M_EXT) == 0) {
                        error = ENOBUFS;
                        goto bad;
Index: sys/net/if_aggr.c
===================================================================
RCS file: /cvs/src/sys/net/if_aggr.c,v
retrieving revision 1.34
diff -u -p -r1.34 if_aggr.c
--- sys/net/if_aggr.c   21 Aug 2020 22:59:27 -0000      1.34
+++ sys/net/if_aggr.c   7 Oct 2020 19:47:04 -0000
@@ -2664,7 +2664,7 @@ aggr_ntt_transmit(struct aggr_port *p)
                return;
 
        if (len > MHLEN) {
-               MCLGETI(m, M_DONTWAIT, NULL, len);
+               MCLGETL(m, M_DONTWAIT, len);
                if (!ISSET(m->m_flags, M_EXT)) {
                        m_freem(m);
                        return;
Index: sys/net/if_gre.c
===================================================================
RCS file: /cvs/src/sys/net/if_gre.c,v
retrieving revision 1.160
diff -u -p -r1.160 if_gre.c
--- sys/net/if_gre.c    28 Aug 2020 12:01:48 -0000      1.160
+++ sys/net/if_gre.c    7 Oct 2020 19:47:27 -0000
@@ -3198,7 +3198,7 @@ gre_keepalive_send(void *arg)
                return;
 
        if (len > MHLEN) {
-               MCLGETI(m, M_DONTWAIT, NULL, len);
+               MCLGETL(m, M_DONTWAIT, len);
                if (!ISSET(m->m_flags, M_EXT)) {
                        m_freem(m);
                        return;
@@ -4099,7 +4099,7 @@ eoip_keepalive_send(void *arg)
                return;
 
        if (linkhdr > MHLEN) {
-               MCLGETI(m, M_DONTWAIT, NULL, linkhdr);
+               MCLGETL(m, M_DONTWAIT, linkhdr);
                if (!ISSET(m->m_flags, M_EXT)) {
                        m_freem(m);
                        return;
Index: sys/net/if_pfsync.c
===================================================================
RCS file: /cvs/src/sys/net/if_pfsync.c,v
retrieving revision 1.278
diff -u -p -r1.278 if_pfsync.c
--- sys/net/if_pfsync.c 24 Aug 2020 15:30:58 -0000      1.278
+++ sys/net/if_pfsync.c 7 Oct 2020 19:47:43 -0000
@@ -1627,7 +1627,7 @@ pfsync_sendout(void)
        }
 
        if (max_linkhdr + sc->sc_len > MHLEN) {
-               MCLGETI(m, M_DONTWAIT, NULL, max_linkhdr + sc->sc_len);
+               MCLGETL(m, M_DONTWAIT, max_linkhdr + sc->sc_len);
                if (!ISSET(m->m_flags, M_EXT)) {
                        m_free(m);
                        sc->sc_if.if_oerrors++;
Index: sys/net/switchctl.c
===================================================================
RCS file: /cvs/src/sys/net/switchctl.c,v
retrieving revision 1.21
diff -u -p -r1.21 switchctl.c
--- sys/net/switchctl.c 7 Apr 2020 13:27:52 -0000       1.21
+++ sys/net/switchctl.c 7 Oct 2020 19:48:08 -0000
@@ -224,7 +224,7 @@ switchwrite(dev_t dev, struct uio *uio, 
                if (m == NULL)
                        return (ENOBUFS);
                if (len >= MHLEN) {
-                       MCLGETI(m, M_DONTWAIT, NULL, MIN(MAXMCLBYTES, len));
+                       MCLGETL(m, M_DONTWAIT, MIN(MAXMCLBYTES, len));
                        if ((m->m_flags & M_EXT) == 0) {
                                m_free(m);
                                return (ENOBUFS);
@@ -262,7 +262,7 @@ switchwrite(dev_t dev, struct uio *uio, 
                        goto save_return;
                }
                if (len >= MLEN) {
-                       MCLGETI(n, M_DONTWAIT, NULL, MIN(MAXMCLBYTES, len));
+                       MCLGETL(n, M_DONTWAIT, MIN(MAXMCLBYTES, len));
                        if ((n->m_flags & M_EXT) == 0) {
                                m_free(n);
                                error = ENOBUFS;
Index: sys/sys/mbuf.h
===================================================================
RCS file: /cvs/src/sys/sys/mbuf.h,v
retrieving revision 1.250
diff -u -p -r1.250 mbuf.h
--- sys/sys/mbuf.h      8 Aug 2020 19:53:02 -0000       1.250
+++ sys/sys/mbuf.h      7 Oct 2020 19:25:36 -0000
@@ -312,7 +312,7 @@ struct mbuf {
 } while (/* CONSTCOND */ 0)
 
 #define MCLGET(m, how) (void) m_clget((m), (how), MCLBYTES)
-#define MCLGETI(m, how, ifp, l) m_clget((m), (how), (l))
+#define MCLGETL(m, how, l) m_clget((m), (how), (l))
 
 u_int mextfree_register(void (*)(caddr_t, u_int, void *));
 #define        MEXTFREE_POOL 0

Reply via email to
Index: sys/dev/ic/ar5008.c
===================================================================
RCS file: /cvs/src/sys/dev/ic/ar5008.c,v
retrieving revision 1.61
diff -u -p -r1.61 ar5008.c
--- sys/dev/ic/ar5008.c 13 Jul 2020 08:31:32 -0000      1.61
+++ sys/dev/ic/ar5008.c 7 Oct 2020 19:29:40 -0000
@@ -625,9 +625,9 @@ ar5008_rx_alloc(struct athn_softc *sc)
                        goto fail;
                }
                /*
                 * Assumes MCLGETI returns cache-line-size aligned buffers.
                 */
-               bf->bf_m = MCLGETI(NULL, M_DONTWAIT, NULL, ATHN_RXBUFSZ);
+               bf->bf_m = MCLGETL(NULL, M_DONTWAIT, ATHN_RXBUFSZ);
                if (bf->bf_m == NULL) {
                        printf("%s: could not allocate Rx mbuf\n",
                            sc->sc_dev.dv_xname);
@@ -935,7 +935,7 @@ ar5008_rx_process(struct athn_softc *sc,
        }
 
        /* Allocate a new Rx buffer. */
-       m1 = MCLGETI(NULL, M_DONTWAIT, NULL, ATHN_RXBUFSZ);
+       m1 = MCLGETL(NULL, M_DONTWAIT, ATHN_RXBUFSZ);
        if (__predict_false(m1 == NULL)) {
                ic->ic_stats.is_rx_nombuf++;
                ifp->if_ierrors++;
@@ -625,9 +625,9 @@ ar5008_rx_alloc(struct athn_softc *sc)
                }
                /*
-                * Assumes MCLGETI returns cache-line-size aligned buffers.
+                * Assumes MCLGETL returns cache-line-size aligned buffers.
                 */
Index: sys/dev/ic/ar9003.c
===================================================================
RCS file: /cvs/src/sys/dev/ic/ar9003.c,v
retrieving revision 1.50
diff -u -p -r1.50 ar9003.c
--- sys/dev/ic/ar9003.c 17 Feb 2020 20:57:58 -0000      1.50
+++ sys/dev/ic/ar9003.c 7 Oct 2020 19:30:28 -0000
@@ -743,9 +743,9 @@ ar9003_rx_alloc(struct athn_softc *sc, i
                        goto fail;
                }
                /*
                 * Assumes MCLGETI returns cache-line-size aligned buffers.
                 */
-               bf->bf_m = MCLGETI(NULL, M_DONTWAIT, NULL, ATHN_RXBUFSZ);
+               bf->bf_m = MCLGETL(NULL, M_DONTWAIT, ATHN_RXBUFSZ);
                if (bf->bf_m == NULL) {
                        printf("%s: could not allocate Rx mbuf\n",
                            sc->sc_dev.dv_xname);
@@ -970,7 +970,7 @@ ar9003_rx_process(struct athn_softc *sc,
        }
 
        /* Allocate a new Rx buffer. */
-       m1 = MCLGETI(NULL, M_DONTWAIT, NULL, ATHN_RXBUFSZ);
+       m1 = MCLGETL(NULL, M_DONTWAIT, ATHN_RXBUFSZ);
        if (__predict_false(m1 == NULL)) {
                ic->ic_stats.is_rx_nombuf++;
                ifp->if_ierrors++;
@@ -2630,7 +2630,7 @@ ar9003_paprd_tx_tone(struct athn_softc *
        int error;
 
        /* Build a Null (no data) frame of TONE_LEN bytes. */
-       m = MCLGETI(NULL, M_DONTWAIT, NULL, TONE_LEN);
+       m = MCLGETL(NULL, M_DONTWAIT, TONE_LEN);
        if (m == NULL)
                return (ENOBUFS);
        memset(mtod(m, caddr_t), 0, TONE_LEN);
@@ -743,9 +743,9 @@ ar9003_rx_alloc(struct athn_softc *sc, i
                }
                /*
-                * Assumes MCLGETI returns cache-line-size aligned buffers.
+                * Assumes MCLGETL returns cache-line-size aligned buffers.
                 */